==> rapid_widgets_library-0.2.6.tar.gz: lib/custom-scanner.dart <==
/*
Description:
A widget that can be used to scan QR codes and barcodes. Returns data from the QRcode/barcode as
part of the callback return call.
Note: Will require import of barcode_scan: ^1.0.0 using pubspec.yaml

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-scanner.dart';

Usage:
The user passes the parameters of a Floating action button like color, child, shape etc.
The user also passes a callback function that is used to receive the scanned data.

- We have used a dynamic Future function builder that gets called once the Floating action button is pressed.
This function takes care of building a new screen with a camera capable of scanning QR codes and barcodes 
The function returns the value of the scanned data as a part of the callback passed to the widget.

//Defining the objects for the widget
  Floatingactionbuttonparam buttonParameters = new Floatingactionbuttonparam(
        backgroundColor: Colors.red, child: Text('Scan'), heroTag: 'scanner');
    getScannedData(String data) {
      print(data);
    }

//Calling the Widget
CustomQRCodeScanner(buttonParameters, getScannedData)

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'package:barcode_scan/barcode_scan.dart';
import 'package:flutter/services.dart';
import 'package:rapid_widgets_library/custom-floatingActionButton.dart';
import 'package:rapid_widgets_library/consts.dart' as cons;
import 'package:rapid_widgets_library/widget-classesUsed.dart';

// ignore: must_be_immutable
class CustomQRCodeScanner extends StatefulWidget {
  Floatingactionbuttonparam buttonParameters;
  Function(String) callback;
  CustomQRCodeScanner(this.buttonParameters, this.callback);

  @override
  _CustomQRCodeScanner createState() =>
      new _CustomQRCodeScanner(this.buttonParameters, this.callback);
}

class _CustomQRCodeScanner extends State<CustomQRCodeScanner> {
  Floatingactionbuttonparam buttonParameters;
  Function(String) callback;
  _CustomQRCodeScanner(this.buttonParameters, this.callback);

  String scanResult = "";

  Future _scanQR(val) async {
    try {
      ScanResult qrResult = await BarcodeScanner.scan();
      setState(() {
        scanResult = qrResult as String;
      });
    } on PlatformException catch (ex) {
      if (ex.code == BarcodeScanner.cameraAccessDenied) {
        setState(() {
          scanResult = cons.cameraPermissionDenied;
        });
      } else {
        setState(() {
          scanResult = "$ex";
        });
      }
    } on FormatException {
      setState(() {
        scanResult = cons.cameraBackPress;
      });
    } catch (ex) {
      setState(() {
        scanResult = "$ex";
      });
    }
    callback(scanResult);
  }

  @override
  Widget build(BuildContext context) {
    if (buttonParameters == null) {
      return customFloatingActionButton(null, _scanQR);
    } else {
      return customFloatingActionButton(buttonParameters, _scanQR);
    }
  }
}

==> rapid_widgets_library-0.2.33.tar.gz: lib/custom-scanner.dart <==
/*
Description:
A widget that can be used to scan QR codes and barcodes. Returns data from the QRcode/barcode as
part of the callback return call.
Note: Will require import of barcode_scan: ^1.0.0 using pubspec.yaml

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-scanner.dart';

Usage:
The user passes the parameters of a Floating action button like color, child, shape etc.
The user also passes a callback function that is used to receive the scanned data.

- We have used a dynamic Future function builder that gets called once the Floating action button is pressed.
This function takes care of building a new screen with a camera capable of scanning QR codes and barcodes 
The function returns the value of the scanned data as a part of the callback passed to the widget.

//Defining the objects for the widget
  Floatingactionbuttonparam buttonParameters = new Floatingactionbuttonparam(
        backgroundColor: Colors.red, child: Text('Scan'), heroTag: 'scanner');
    getScannedData(String data) {
      print(data);
    }

//Calling the Widget
CustomQRCodeScanner(buttonParameters, getScannedData)

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';

import 'package:flutter/services.dart';
import 'package:rapid_widgets_library/custom-floatingActionButton.dart';
import 'package:rapid_widgets_library/consts.dart' as cons;
import 'package:rapid_widgets_library/widget-classesUsed.dart';

// ignore: must_be_immutable
class CustomQRCodeScanner extends StatefulWidget {
  Floatingactionbuttonparam buttonParameters;
  Function(String) callback;
  CustomQRCodeScanner(this.buttonParameters, this.callback);

  @override
  _CustomQRCodeScanner createState() =>
      new _CustomQRCodeScanner(this.buttonParameters, this.callback);
}

class _CustomQRCodeScanner extends State<CustomQRCodeScanner> {
  Floatingactionbuttonparam buttonParameters;
  Function(String) callback;
  _CustomQRCodeScanner(this.buttonParameters, this.callback);

  String scanResult = "";

  Future _scanQR(val) async {
    // try {
    //   ScanResult qrResult = await BarcodeScanner.scan();
    //   setState(() {
    //     scanResult = qrResult as String;
    //   });
    // } on PlatformException catch (ex) {
    //   if (ex.code == BarcodeScanner.cameraAccessDenied) {
    //     setState(() {
    //       scanResult = cons.cameraPermissionDenied;
    //     });
    //   } else {
    //     setState(() {
    //       scanResult = "$ex";
    //     });
    //   }
    // } on FormatException {
    //   setState(() {
    //     scanResult = cons.cameraBackPress;
    //   });
    // } catch (ex) {
    //   setState(() {
    //     scanResult = "$ex";
    //   });
    // }
    callback(scanResult);
  }

  @override
  Widget build(BuildContext context) {
    if (buttonParameters == null) {
      return customFloatingActionButton(null, _scanQR);
    } else {
      return customFloatingActionButton(buttonParameters, _scanQR);
    }
  }
}
